translate.storage._factory_classes

Package translate :: Package storage :: Module _factory_classes |
[hide private]
[frames] | no frames]

# Source Code for Module translate.storage._factory_classes

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2010 Zuza Software Foundation
     5  #
     6  # This file is part of Virtaal.
     7  #
     8  # This program is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # This program is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with this program; if not, see <http://www.gnu.org/licenses/>.
    20
    21  """Py2exe can't find stuff that we import dynamically, so we have this file
    22  just for the sake of the Windows installer to easily pick up all the stuff that we need and ensure they make it into the installer."""
    23
    24  import csvl10n
    25  import omegat
    26  import po
    27  import mo
    28  import qm
    29  import utx
    30  import wordfast
    31  import catkeys
    32  import qph
    33  import tbx
    34  import tmx
    35  import ts2
    36  import xliff
    37  try:
    38      import trados
    39  except ImportError, e:
    40      pass
    41